pub struct MsgCreateDenom {
pub sender: String,
pub subdenom: String,
}Fields
sender: Stringsubdenom: StringTrait Implementations
Sourceimpl Clone for MsgCreateDenom
impl Clone for MsgCreateDenom
Sourcefn clone(&self) -> MsgCreateDenom
fn clone(&self) -> MsgCreateDenom
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MsgCreateDenom
impl Debug for MsgCreateDenom
Sourceimpl<'de> Deserialize<'de> for MsgCreateDenom
impl<'de> Deserialize<'de> for MsgCreateDenom
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EncodeMessage for MsgCreateDenom
impl EncodeMessage for MsgCreateDenom
Sourceimpl JsonSchema for MsgCreateDenom
impl JsonSchema for MsgCreateDenom
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MsgCreateDenom
impl PartialEq for MsgCreateDenom
Sourcefn eq(&self, other: &MsgCreateDenom) -> bool
fn eq(&self, other: &MsgCreateDenom) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MsgCreateDenom
impl Serialize for MsgCreateDenom
impl StructuralPartialEq for MsgCreateDenom