pub struct MsgCreateDenomResponse {
pub new_token_denom: String,
}Expand description
MsgCreateDenomResponse is the return value of MsgCreateDenom It returns the full string of the newly created denom
Fields
new_token_denom: StringTrait Implementations
Sourceimpl Clone for MsgCreateDenomResponse
impl Clone for MsgCreateDenomResponse
Sourcefn clone(&self) -> MsgCreateDenomResponse
fn clone(&self) -> MsgCreateDenomResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MsgCreateDenomResponse
impl Debug for MsgCreateDenomResponse
Sourceimpl<'de> Deserialize<'de> for MsgCreateDenomResponse
impl<'de> Deserialize<'de> for MsgCreateDenomResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MsgCreateDenomResponse
impl JsonSchema for MsgCreateDenomResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MsgCreateDenomResponse
impl PartialEq for MsgCreateDenomResponse
Sourcefn eq(&self, other: &MsgCreateDenomResponse) -> bool
fn eq(&self, other: &MsgCreateDenomResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MsgCreateDenomResponse
impl Serialize for MsgCreateDenomResponse
impl StructuralPartialEq for MsgCreateDenomResponse