pub struct QueryParamsResponse {
pub params: Option<Params>,
}Expand description
QueryParamsResponse is the response type for the Query/Params RPC method.
Fields
params: Option<Params>Trait Implementations
Sourceimpl Clone for QueryParamsResponse
impl Clone for QueryParamsResponse
Sourcefn clone(&self) -> QueryParamsResponse
fn clone(&self) -> QueryParamsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryParamsResponse
impl Debug for QueryParamsResponse
Sourceimpl<'de> Deserialize<'de> for QueryParamsResponse
impl<'de> Deserialize<'de> for QueryParamsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryParamsResponse
impl JsonSchema for QueryParamsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QueryParamsResponse
impl PartialEq for QueryParamsResponse
Sourcefn eq(&self, other: &QueryParamsResponse) -> bool
fn eq(&self, other: &QueryParamsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for QueryParamsResponse
impl Serialize for QueryParamsResponse
impl StructuralPartialEq for QueryParamsResponse