pub struct MsgSetBeforeSendHook {
pub sender: String,
pub denom: String,
pub contract_addr: String,
}Fields
sender: Stringdenom: Stringcontract_addr: StringTrait Implementations
Sourceimpl Clone for MsgSetBeforeSendHook
impl Clone for MsgSetBeforeSendHook
Sourcefn clone(&self) -> MsgSetBeforeSendHook
fn clone(&self) -> MsgSetBeforeSendHook
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MsgSetBeforeSendHook
impl Debug for MsgSetBeforeSendHook
Sourceimpl<'de> Deserialize<'de> for MsgSetBeforeSendHook
impl<'de> Deserialize<'de> for MsgSetBeforeSendHook
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EncodeMessage for MsgSetBeforeSendHook
impl EncodeMessage for MsgSetBeforeSendHook
Sourceimpl JsonSchema for MsgSetBeforeSendHook
impl JsonSchema for MsgSetBeforeSendHook
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MsgSetBeforeSendHook
impl PartialEq for MsgSetBeforeSendHook
Sourcefn eq(&self, other: &MsgSetBeforeSendHook) -> bool
fn eq(&self, other: &MsgSetBeforeSendHook) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MsgSetBeforeSendHook
impl Serialize for MsgSetBeforeSendHook
impl StructuralPartialEq for MsgSetBeforeSendHook